@@ -1,4 +1,5 @@
 import abc
+import asyncio
 import logging
 from typing import Any, Callable, List, Optional, TYPE_CHECKING, Union
 
@@ -8,12 +9,11 @@ from discord.ext.commands import Context
 
 from dpymenus import Page, PagesError, Session, SessionError
 from dpymenus.hooks import HookEvent, HookWhen, call_hook
-from dpymenus.settings import HISTORY_CACHE_LIMIT, REPLY_AS_DEFAULT, TIMEOUT
+from dpymenus.settings import BUTTON_DELAY, HISTORY_CACHE_LIMIT, REPLY_AS_DEFAULT, TIMEOUT
 
 if TYPE_CHECKING:
     from dpymenus import Template
     from dpymenus.types import PageType
-    from dpymenus.sessions import SessionKey
 
 
 class BaseMenu(abc.ABC):
@@ -144,8 +144,8 @@ class BaseMenu(abc.ABC):
 
     def add_hook(self, when: HookWhen, event: HookEvent, callback: Callable) -> 'BaseMenu':
         """Sets various callback attributes on the menu so users can hook into
-        specific events. See https://github.com/robertwayne/dpymenus-book#hooks
-        for the full list of events and hook structure.
+        specific events. See https://dpymenus.com/lifecycle for the full list of events
+        and hook structure.
 
         :param when: Defines which point in the menu lifetime the callback will be executed.
         :param event: Defines which event in the menu lifetime the callback will be executed on.
@@ -164,6 +164,10 @@ class BaseMenu(abc.ABC):
         Session.get(self).kill_or_freeze()
         self.active = False
 
+        if self.output.reactions:
+            await asyncio.sleep(BUTTON_DELAY)
+            await self._safe_clear_reactions()
+
         await self._safe_delete_output()
         await call_hook(self, '_hook_after_close')
 
@@ -290,10 +294,8 @@ class BaseMenu(abc.ABC):
     async def _safe_delete_input(self):
         """Safely deletes a message if the bot has permissions and show command messages is set to false."""
         if self.command_message is False:
-            try:
+            if isinstance(self.output.channel, GuildChannel):
                 await self.input.delete()
-            except PermissionError:
-                return
 
     async def _safe_delete_output(self):
         """Safely deletes a message if the bot has permissions and persist is set to false."""
